==> customer-link-project-api-0.0.25-20221202.090336-3-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app87225/vo/GoodsVO.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app87225.vo;

/**
 * @author zht
 * @description
 * @createTime 2022年12月01日
 */
public class GoodsVO {

    /**
     * 品牌名称
     */
    private String brandName;
    /**
     * 售价
     */
    private Double salePrice;
    /**
     * 是否有效 0-无效，1-有效
     */
    private Integer isValid;
    /**
     * 装修编辑状态 1-编辑，2-发布
     */
    private String editStatus;
    /**
     * 店铺名称
     */
    private String shopName;
    /**
     * 更新人
     */
    private String updateUser;
    /**
     * 更新时间
     */
    private String updateTime;
    /**
     *
     */
    private String tagPrice;
    /**
     * 品牌编号
     */
    private String brandDetailNo;
    /**
     * 装修模板id
     */
    private String templateId;
    /**
     * 店铺商品id
     */
    private String shopCommodityId;
    /**
     * 排序字段
     */
    private String productName;
    /**
     *
     */
    private Integer sortNo;
    /**
     * 商品货号
     */
    private String productCode;
    /**
     * 创建时间
     */
    private String createTime;
    /**
     * 缩略图地址
     */
    private String thumbnailPath;
    /**
     * 创建人
     */
    private String createUser;
    /**
     * 装修商品ID
     */
    private String id;
    /**
     *
     */
    private String orderByClause;
    /**
     *
     */
    private Integer clientIsVisible;
    /**
     * 店铺编码
     */
    private String shopNo;
    /**
     * qs等级
     */
    private String zoneQsLevel;

    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }

    public Double getSalePrice() {
        return salePrice;
    }

    public void setSalePrice(Double salePrice) {
        this.salePrice = salePrice;
    }

    public Integer getIsValid() {
        return isValid;
    }

    public void setIsValid(Integer isValid) {
        this.isValid = isValid;
    }

    public String getEditStatus() {
        return editStatus;
    }

    public void setEditStatus(String editStatus) {
        this.editStatus = editStatus;
    }

    public String getShopName() {
        return shopName;
    }

    public void setShopName(String shopName) {
        this.shopName = shopName;
    }

    public String getUpdateUser() {
        return updateUser;
    }

    public void setUpdateUser(String updateUser) {
        this.updateUser = updateUser;
    }

    public String getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(String updateTime) {
        this.updateTime = updateTime;
    }

    public String getTagPrice() {
        return tagPrice;
    }

    public void setTagPrice(String tagPrice) {
        this.tagPrice = tagPrice;
    }

    public String getBrandDetailNo() {
        return brandDetailNo;
    }

    public void setBrandDetailNo(String brandDetailNo) {
        this.brandDetailNo = brandDetailNo;
    }

    public String getTemplateId() {
        return templateId;
    }

    public void setTemplateId(String templateId) {
        this.templateId = templateId;
    }

    public String getShopCommodityId() {
        return shopCommodityId;
    }

    public void setShopCommodityId(String shopCommodityId) {
        this.shopCommodityId = shopCommodityId;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public Integer getSortNo() {
        return sortNo;
    }

    public void setSortNo(Integer sortNo) {
        this.sortNo = sortNo;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public String getThumbnailPath() {
        return thumbnailPath;
    }

    public void setThumbnailPath(String thumbnailPath) {
        this.thumbnailPath = thumbnailPath;
    }

    public String getCreateUser() {
        return createUser;
    }

    public void setCreateUser(String createUser) {
        this.createUser = createUser;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getOrderByClause() {
        return orderByClause;
    }

    public void setOrderByClause(String orderByClause) {
        this.orderByClause = orderByClause;
    }

    public Integer getClientIsVisible() {
        return clientIsVisible;
    }

    public void setClientIsVisible(Integer clientIsVisible) {
        this.clientIsVisible = clientIsVisible;
    }

    public String getShopNo() {
        return shopNo;
    }

    public void setShopNo(String shopNo) {
        this.shopNo = shopNo;
    }

    public String getZoneQsLevel() {
        return zoneQsLevel;
    }

    public void setZoneQsLevel(String zoneQsLevel) {
        this.zoneQsLevel = zoneQsLevel;
    }
}

==> customer-link-project-api-1.1.25-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app87225/vo/GoodsVO.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app87225.vo;

/**
 * @author zht
 * @description
 * @createTime 2022年12月01日
 */
public class GoodsVO {

    /**
     * 品牌名称
     */
    private String brandName;
    /**
     * 售价
     */
    private String salePrice;
    /**
     * 是否有效 0-无效，1-有效
     */
    private Integer isValid;
    /**
     * 装修编辑状态 1-编辑，2-发布
     */
    private String editStatus;
    /**
     * 店铺名称
     */
    private String shopName;
    /**
     * 更新人
     */
    private String updateUser;
    /**
     * 更新时间
     */
    private String updateTime;
    /**
     *
     */
    private String tagPrice;
    /**
     * 品牌编号
     */
    private String brandDetailNo;
    /**
     * 装修模板id
     */
    private String templateId;
    /**
     * 店铺商品id
     */
    private String shopCommodityId;
    /**
     * 排序字段
     */
    private String productName;
    /**
     *
     */
    private Integer sortNo;
    /**
     * 商品货号
     */
    private String productCode;
    /**
     * 创建时间
     */
    private String createTime;
    /**
     * 缩略图地址
     */
    private String thumbnailPath;
    /**
     * 创建人
     */
    private String createUser;
    /**
     * 装修商品ID
     */
    private String id;
    /**
     *
     */
    private String orderByClause;
    /**
     *
     */
    private Integer clientIsVisible;
    /**
     * 店铺编码
     */
    private String shopNo;
    /**
     * qs等级
     */
    private String zoneQsLevel;

    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }

    public String getSalePrice() {
        return salePrice;
    }

    public void setSalePrice(String salePrice) {
        this.salePrice = salePrice;
    }

    public Integer getIsValid() {
        return isValid;
    }

    public void setIsValid(Integer isValid) {
        this.isValid = isValid;
    }

    public String getEditStatus() {
        return editStatus;
    }

    public void setEditStatus(String editStatus) {
        this.editStatus = editStatus;
    }

    public String getShopName() {
        return shopName;
    }

    public void setShopName(String shopName) {
        this.shopName = shopName;
    }

    public String getUpdateUser() {
        return updateUser;
    }

    public void setUpdateUser(String updateUser) {
        this.updateUser = updateUser;
    }

    public String getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(String updateTime) {
        this.updateTime = updateTime;
    }

    public String getTagPrice() {
        return tagPrice;
    }

    public void setTagPrice(String tagPrice) {
        this.tagPrice = tagPrice;
    }

    public String getBrandDetailNo() {
        return brandDetailNo;
    }

    public void setBrandDetailNo(String brandDetailNo) {
        this.brandDetailNo = brandDetailNo;
    }

    public String getTemplateId() {
        return templateId;
    }

    public void setTemplateId(String templateId) {
        this.templateId = templateId;
    }

    public String getShopCommodityId() {
        return shopCommodityId;
    }

    public void setShopCommodityId(String shopCommodityId) {
        this.shopCommodityId = shopCommodityId;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public Integer getSortNo() {
        return sortNo;
    }

    public void setSortNo(Integer sortNo) {
        this.sortNo = sortNo;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public String getThumbnailPath() {
        return thumbnailPath;
    }

    public void setThumbnailPath(String thumbnailPath) {
        this.thumbnailPath = thumbnailPath;
    }

    public String getCreateUser() {
        return createUser;
    }

    public void setCreateUser(String createUser) {
        this.createUser = createUser;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getOrderByClause() {
        return orderByClause;
    }

    public void setOrderByClause(String orderByClause) {
        this.orderByClause = orderByClause;
    }

    public Integer getClientIsVisible() {
        return clientIsVisible;
    }

    public void setClientIsVisible(Integer clientIsVisible) {
        this.clientIsVisible = clientIsVisible;
    }

    public String getShopNo() {
        return shopNo;
    }

    public void setShopNo(String shopNo) {
        this.shopNo = shopNo;
    }

    public String getZoneQsLevel() {
        return zoneQsLevel;
    }

    public void setZoneQsLevel(String zoneQsLevel) {
        this.zoneQsLevel = zoneQsLevel;
    }
}
